import lazyValue from "lazy-value";
import { readLogoSizing } from "../readLogoSizing.js";
import { getUsageFromReadme } from "./getUsageFromReadme.js";
function readDefaultsFromReadme(readme, repository) {
  const imageTag = lazyValue(
    async () => /\n<img.+src=.+>/.exec(await readme())?.[0]
  );
  return {
    logo: async () => {
      const tag = await imageTag();
      if (!tag) {
        return void 0;
      }
      const src = /src\s*=(.+)['"/]>/.exec(tag)?.[1]?.replaceAll(/^['"]|['"]$/g, "");
      if (!src) {
        return void 0;
      }
      return {
        alt: /alt=['"](.+)['"]\s*src=/.exec(tag)?.[1] ?? "Project logo",
        src,
        ...readLogoSizing(src)
      };
    },
    title: async () => {
      const text = await readme();
      return (/^<h1\s+align="center">(.+)<\/h1>/.exec(text) ?? /^# (.+)/.exec(text))?.[1];
    },
    usage: async () => {
      return getUsageFromReadme(await readme()) ?? `\`\`\`shell
npm i ${repository}
\`\`\`
\`\`\`ts
import { greet } from "${repository}";

greet("Hello, world! \u{1F496}");
\`\`\``;
    }
  };
}
export {
  readDefaultsFromReadme
};
//# sourceMappingURL=readDefaultsFromReadme.js.map